@@ -264,6 +264,36 @@ bool InvoiceOperations::invoiceNumberExists(const QString &targetBasePath, const
     return false;
 }
 
+QStringList InvoiceOperations::findDuplicateInvoiceFolders(const QString &targetBasePath, const QString &invoiceNumber)
+{
+    QStringList result;
+    if (invoiceNumber.isEmpty() || targetBasePath.isEmpty()) {
+        return result;
+    }
+
+    QString cleanInvoiceNumber = QString(invoiceNumber).replace(" ", "-");
+    QDir dir(targetBasePath);
+
+    if (!dir.exists()) {
+        return result;
+    }
+
+    QStringList entries = dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
+    for (const QString &entry : entries) {
+        QString directoryFile = targetBasePath + "/" + entry + "/.directory";
+        QSettings settings(directoryFile, QSettings::IniFormat);
+        settings.beginGroup("X-XRDialog-Invoice");
+        QString existingId = settings.value("ID", "").toString();
+        settings.endGroup();
+
+        if (!existingId.isEmpty() && existingId == cleanInvoiceNumber) {
+            result.append(entry);
+        }
+    }
+
+    return result;
+}
+
 bool InvoiceOperations::createNoticeFile(const QString &folderPath, const QString &date, const QString &noticeText)
 {
     if (noticeText.isEmpty()) {
